﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Media;
using System.Windows.Threading;

namespace XamDataChartBubbleSeriesColorCase
{
    public class BubbleDataSample : BubbleDataCollection
    {
        public BubbleDataSample()
        {
            List<BubbleDataPoint> items = new List<BubbleDataPoint>
            {
                new BubbleDataPoint {X = 100, Y = 100, Radius = 50},
                new BubbleDataPoint {X = 80, Y = 80, Radius = 35},
                new BubbleDataPoint {X = 80, Y = 160, Radius = 35},
                new BubbleDataPoint {X = 160, Y = 80, Radius = 35},
                new BubbleDataPoint {X = 160, Y = 160, Radius = 35},
                new BubbleDataPoint {X = 60, Y = 60, Radius = 25},
                new BubbleDataPoint {X = 60, Y = 140, Radius = 25},
                new BubbleDataPoint {X = 140, Y = 60, Radius = 25},
                new BubbleDataPoint {X = 140, Y = 140, Radius = 25},
                new BubbleDataPoint {X = 40, Y = 40, Radius = 15},
                new BubbleDataPoint {X = 40, Y = 120, Radius = 15},
                new BubbleDataPoint {X = 120, Y = 40, Radius = 15},
                new BubbleDataPoint {X = 120, Y = 120, Radius = 15},
                new BubbleDataPoint {X = 20, Y = 20, Radius = 10},
                new BubbleDataPoint {X = 20, Y = 180, Radius = 10},
                new BubbleDataPoint {X = 180, Y = 20, Radius = 10},
                new BubbleDataPoint {X = 180, Y = 180, Radius = 10}
            };

            var sortedItems = items.OrderByDescending(item => item.Radius).ToArray();
            for (int i = 0; i < sortedItems.Count(); i++)
            {
                sortedItems[i].Label = "Item " + (i + 1);
                this.Add(sortedItems[i]);
            }

            RadialGradientBrush RGB1 = new RadialGradientBrush(Colors.White, Colors.Red);
            RadialGradientBrush RGB2 = new RadialGradientBrush(Colors.White, Colors.Green);
            RadialGradientBrush RGB3 = new RadialGradientBrush(Colors.White, Colors.Blue);
            foreach (BubbleDataPoint BDP in items)
            {              
                if (BDP.Y > BDP.X)
                {
                    BDP.BubbleBrush = RGB1;
                }
                else if (BDP.Y == BDP.X)
                {
                    BDP.BubbleBrush = RGB2;
                }
                else
                {
                    BDP.BubbleBrush = RGB3;
                }
            }
        }
    }
    public class BubbleDataCollection : ObservableCollection<BubbleDataPoint>
    { }
    public class BubbleDataPoint : ObservableModel
    {

        #region Properties

        private double _y;
        public double Y
        {
            get { return _y; }
            set { if (_y == value) return; _y = value; OnPropertyChanged("Y"); }
        }

        private double _x;
        public double X
        {
            get { return _x; }
            set { if (_x == value) return; _x = value; OnPropertyChanged("X"); }
        }

        private double _radius;
        public double Radius
        {
            get { return _radius; }
            set { if (_radius == value) return; _radius = value; OnPropertyChanged("Radius"); }
        }

        private string _label;
        public string Label
        {
            get { return _label; }
            set { if (_label == value) return; _label = value; OnPropertyChanged("Label"); }
        }

        private Brush _brush;
        public Brush BubbleBrush
        {
            get { return _brush; }
            set { if (_brush == value) return; _brush = value; OnPropertyChanged("BubbleBrush"); }
        }

        #endregion

        public new string ToString()
        {
            return String.Format("X {0}, Y {1}, Radius {2}", X, Y, Radius);
        }

    }
    public abstract class ObservableModel : INotifyPropertyChanged
    {
        protected ObservableModel()
        {

        }

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
                handler(this, new PropertyChangedEventArgs(propertyName));
        }

        public void OnAsyncPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {

                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));

            }
        }
        #endregion
    }  
}
